==> owncloud-8.1.0p2.tgz: owncloud/apps/files_sharing/l10n/sr.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Дељење између сервера није укључено на овом серверу",
    "The mountpoint name contains invalid characters." : "Назив тачке монтирања садржи неисправне знакове.",
    "Invalid or untrusted SSL certificate" : "Неисправан или неповерљив ССЛ сертификат",
    "Could not authenticate to remote share, password might be wrong" : "Не могу да се пријавим на удаљено дељење. Лозинка је можда погрешна",
    "Storage not valid" : "Складиште није исправно",
    "Couldn't add remote share" : "Не могу да додам удаљено дељење",
    "Shared with you" : "Дељено са вама",
    "Shared with others" : "Дељено са осталима",
    "Shared by link" : "Дељено путем везе",
    "Nothing shared with you yet" : "Још увек се ништа са вама не дели",
    "Files and folders others share with you will show up here" : "Фајлови и фасцикле које други деле са вама појавиће се овде",
    "Nothing shared yet" : "Још се ништа не дели",
    "Files and folders you share will show up here" : "Фајлови и фасцикле које делите појавиће се овде",
    "No shared links" : "Нема веза за дељење",
    "Files and folders you share by link will show up here" : "Фајлови и фасцикле које делите путем везе појавиће се овде",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Желите ли да додате удаљено дељење {name} власника {owner}@{remote}?",
    "Remote share" : "Удаљено дељење",
    "Remote share password" : "Лозинка удаљеног дељења",
    "Cancel" : "Одустани",
    "Add remote share" : "Додај удаљено дељење",
    "You can upload into this folder" : "Можете да отпремате у ову фасциклу",
    "No ownCloud installation (7 or higher) found at {remote}" : "Нема оунКлауд инсталације верзије 7 или више на {remote}",
    "Invalid ownCloud url" : "Неисправан оунКлауд УРЛ",
    "Share" : "Дељење",
    "Shared by" : "Дели",
    "A file or folder has been <strong>shared</strong>" : "Фајл или фасцикла је <strong>дељен</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Фајл или фасцикла су дељени са <strong>другог сервера</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "Јавно дељени фајл или фасцикла су <strong>преузети</strong>",
    "You received a new remote share from %s" : "Добили сте ново удаљено дељење од %s",
    "%1$s accepted remote share %2$s" : "%1$s прихвати удаљено дељење %2$s",
    "%1$s declined remote share %2$s" : "%1$s одби удаљено дељење %2$s",
    "%1$s unshared %2$s from you" : "%1$s не дели %2$s са вама",
    "Public shared folder %1$s was downloaded" : "Јавно дељена фасцикла %1$s је преузета",
    "Public shared file %1$s was downloaded" : "Јавно дељени фајл %1$s је преузет",
    "You shared %1$s with %2$s" : "Поделили сте %1$s са %2$s",
    "You shared %1$s with group %2$s" : "Поделили сте %1$s са групом %2$s",
    "%2$s shared %1$s with you" : "%2$s подели %1$s са вама",
    "You shared %1$s via link" : "Поделили сте %1$s путем везе",
    "Shares" : "Дељења",
    "This share is password-protected" : "Дељење је заштићено лозинком",
    "The password is wrong. Try again." : "Лозинка је погрешна. Покушајте поново.",
    "Password" : "Лозинка",
    "No entries found in this folder" : "Нема ничега у овој фасцикли",
    "Name" : "Назив",
    "Share time" : "Време дељења",
    "Sorry, this link doesn’t seem to work anymore." : "Нажалост, изгледа да веза више не ради.",
    "Reasons might be:" : "Разлози могу бити:",
    "the item was removed" : "ставка је уклоњена",
    "the link expired" : "веза је истекла",
    "sharing is disabled" : "дељење је искључено",
    "For more info, please ask the person who sent this link." : "За више информација, питајте особу која вам је послала везу.",
    "Add to your ownCloud" : "Додај у свој облак",
    "Download" : "Преузми",
    "Download %s" : "Преузми %s",
    "Direct link" : "Директна веза",
    "Federated Cloud Sharing" : "Здружено дељење у облаку",
    "Open documentation" : "Отвори документацију",
    "Allow users on this server to send shares to other servers" : "Дозвољава корисницима овог сервера да шаљу дељења на друге сервере",
    "Allow users on this server to receive shares from other servers" : "Дозвољава корисницима овог сервера да примају дељења са других сервера",
    "Federated Cloud" : "Здружени облак"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> owncloud-9.0.3.tgz: owncloud/apps/files_sharing/l10n/sr.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Дељење између сервера није укључено на овом серверу",
    "The mountpoint name contains invalid characters." : "Назив тачке монтирања садржи неисправне знакове.",
    "Invalid or untrusted SSL certificate" : "Неисправан или неповерљив ССЛ сертификат",
    "Could not authenticate to remote share, password might be wrong" : "Не могу да се пријавим на удаљено дељење. Лозинка је можда погрешна",
    "Storage not valid" : "Складиште није исправно",
    "Couldn't add remote share" : "Не могу да додам удаљено дељење",
    "Shared with you" : "Дељено са вама",
    "Shared with others" : "Дељено са осталима",
    "Shared by link" : "Дељено путем везе",
    "Nothing shared with you yet" : "Још увек се ништа са вама не дели",
    "Files and folders others share with you will show up here" : "Фајлови и фасцикле које други деле са вама појавиће се овде",
    "Nothing shared yet" : "Још се ништа не дели",
    "Files and folders you share will show up here" : "Фајлови и фасцикле које делите појавиће се овде",
    "No shared links" : "Нема веза за дељење",
    "Files and folders you share by link will show up here" : "Фајлови и фасцикле које делите путем везе појавиће се овде",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Желите ли да додате удаљено дељење {name} власника {owner}@{remote}?",
    "Remote share" : "Удаљено дељење",
    "Remote share password" : "Лозинка удаљеног дељења",
    "Cancel" : "Одустани",
    "Add remote share" : "Додај удаљено дељење",
    "You can upload into this folder" : "Можете да отпремате у ову фасциклу",
    "No ownCloud installation (7 or higher) found at {remote}" : "Нема оунКлауд инсталације верзије 7 или више на {remote}",
    "Invalid ownCloud url" : "Неисправан оунКлауд УРЛ",
    "Shared by" : "Дели",
    "Sharing" : "Дељење",
    "A file or folder has been <strong>shared</strong>" : "Фајл или фасцикла је <strong>дељен</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Фајл или фасцикла су дељени са <strong>другог сервера</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "Јавно дељени фајл или фасцикла су <strong>преузети</strong>",
    "You received a new remote share from %s" : "Добили сте ново удаљено дељење од %s",
    "%1$s accepted remote share %2$s" : "%1$s прихвати удаљено дељење %2$s",
    "%1$s declined remote share %2$s" : "%1$s одби удаљено дељење %2$s",
    "%1$s unshared %2$s from you" : "%1$s не дели %2$s са вама",
    "Public shared folder %1$s was downloaded" : "Јавно дељена фасцикла %1$s је преузета",
    "Public shared file %1$s was downloaded" : "Јавно дељени фајл %1$s је преузет",
    "You shared %1$s with %2$s" : "Поделили сте %1$s са %2$s",
    "You shared %1$s with group %2$s" : "Поделили сте %1$s са групом %2$s",
    "You shared %1$s via link" : "Поделили сте %1$s путем везе",
    "%2$s shared %1$s with you" : "%2$s подели %1$s са вама",
    "Shares" : "Дељења",
    "Accept" : "Прихвати",
    "This share is password-protected" : "Дељење је заштићено лозинком",
    "The password is wrong. Try again." : "Лозинка је погрешна. Покушајте поново.",
    "Password" : "Лозинка",
    "No entries found in this folder" : "Нема ничега у овој фасцикли",
    "Name" : "Назив",
    "Share time" : "Време дељења",
    "Sorry, this link doesn’t seem to work anymore." : "Нажалост, изгледа да веза више не ради.",
    "Reasons might be:" : "Разлози могу бити:",
    "the item was removed" : "ставка је уклоњена",
    "the link expired" : "веза је истекла",
    "sharing is disabled" : "дељење је искључено",
    "For more info, please ask the person who sent this link." : "За више информација, питајте особу која вам је послала везу.",
    "Add to your ownCloud" : "Додај у свој облак",
    "Download" : "Преузми",
    "Download %s" : "Преузми %s",
    "Direct link" : "Директна веза",
    "Federated Cloud Sharing" : "Здружено дељење у облаку",
    "Open documentation" : "Отвори документацију",
    "Allow users on this server to send shares to other servers" : "Дозвољава корисницима овог сервера да шаљу дељења на друге сервере",
    "Allow users on this server to receive shares from other servers" : "Дозвољава корисницима овог сервера да примају дељења са других сервера",
    "Federated Cloud" : "Здружени облак",
    "Decline" : "Одбиј",
    "Federated sharing" : "Здружено дељење",
    "Public shared file %1$s was downloaded" : "Јавно дељени фајл %1$s је преузет",
    "Public shared folder %1$s was downloaded" : "Јавно дељена фасцикла %1$s је преузета"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
